package com.ruoyi.mall.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallAppOrderGoods;
import com.ruoyi.mall.domain.dto.MallAppOrderGoodsDTO;

/**
 * app-线下订单商品Service接口
 *
 * @author ruoyi
 * @date 2024-06-29
 */
public interface IMallAppOrderGoodsService
{
    /**
     * 查询app-线下订单商品
     *
     * @param id app-线下订单商品主键
     * @return app-线下订单商品
     */
    public MallAppOrderGoods selectMallAppOrderGoodsById(Long id);

    /**
     * 查询app-线下订单商品列表
     *
     * @param mallAppOrderGoods app-线下订单商品
     * @return app-线下订单商品集合
     */
    public List<MallAppOrderGoods> selectMallAppOrderGoodsList(MallAppOrderGoods mallAppOrderGoods);

    /**
     * 新增app-线下订单商品
     *
     * @param mallAppOrderGoods app-线下订单商品
     * @return 结果
     */
    public int insertMallAppOrderGoods(MallAppOrderGoods mallAppOrderGoods);

    /**
     * 修改app-线下订单商品
     *
     * @param mallAppOrderGoods app-线下订单商品
     * @return 结果
     */
    public int updateMallAppOrderGoods(MallAppOrderGoods mallAppOrderGoods);

    /**
     * 批量删除app-线下订单商品
     *
     * @param ids 需要删除的app-线下订单商品主键集合
     * @return 结果
     */
    public int deleteMallAppOrderGoodsByIds(Long[] ids);

    /**
     * 删除app-线下订单商品信息
     *
     * @param id app-线下订单商品主键
     * @return 结果
     */
    public int deleteMallAppOrderGoodsById(Long id);

    /**
     * 批量新增app-线下订单商品
     *
     * @param list app-线下订单商品列表
     * @return 结果
     */
    public int bachInsertMallAppOrderGoods(List<MallAppOrderGoodsDTO> list, Long orderId, String orderNo);

    /**
     * 查询app-线下订单商品列表
     *
     * @param orderId app-线下订单ID
     * @return app-线下订单商品
     */
    public List<MallAppOrderGoods> selectMallAppOrderGoodsListByOrderId(Long orderId);

    /**
     * 删除app-线下订单商品信息
     *
     * @param orderId app-线下订单ID
     * @return 结果
     */
    public int deleteMallAppOrderGoodsByOrderId(Long orderId);

    /**
     * 查询app-线下订单商品名称列表
     *
     * @param params 参数
     * @return app-线下订单商品集合
     */
    public List<Map<String, Object>> getAppGoodsNameList(Map<String, Object> params);
}
